element_rows

Function element_rows 

pub fn element_rows(
    element: &str,
    spelling: Spelling,
) -> Option<&'static [&'static str]>
The schema rows element reads, in spelling, when it does not read them all (ElementDef::jsx_rows); None for an element that takes every row, and for one the table does not know.