pub struct Unresolved {
pub token: String,
pub source: String,
}Expand description
Why a derived token was dropped at declaration: the name it was given and the source or operand that resolved to no colour token declared before it and no theme role.
Fields
token: Stringsource: StringTrait Implementations
Sourceimpl Clone for Unresolved
impl Clone for Unresolved
Sourcefn clone(&self) -> Unresolved
fn clone(&self) -> Unresolved
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Unresolved
impl Debug for Unresolved
impl Eq for Unresolved
Sourceimpl PartialEq for Unresolved
impl PartialEq for Unresolved
impl StructuralPartialEq for Unresolved