pub struct FontEntry {
pub family: String,
pub faces: Vec<ID>,
/* private fields */
}Expand description
A registered font: the family name shaping resolves it by, the faces it loaded into the font database (empty for installed fonts), and the weights the family is asked at for regular and bold.
Fields
family: Stringfaces: Vec<ID>Auto Trait Implementations
impl Freeze for FontEntry
impl RefUnwindSafe for FontEntry
impl Send for FontEntry
impl Sync for FontEntry
impl Unpin for FontEntry
impl UnsafeUnpin for FontEntry
impl UnwindSafe for FontEntry